module SystemLibary exposing (..)

import Html exposing (Html, a, button, div, fieldset, figure, footer, h2, img, input, section, text)
import Html.Attributes exposing (class, href, placeholder, src, type_, value)
import Html.Events exposing (onClick, onInput)
import Types exposing (..)

buttonsSystemLibary : SystemLoadingState -> Html Msg
buttonsSystemLibary loadingSys =
    div [ class "mb-4" ]
        [ button [ class "button is-primary mr-4", href "" ]
            [ a [ class "has-text-black" ] [ text "Zurück" ] ]
        , if loadingSys == LoadingS then
            button [ class "button is-warning is-loading mr-2" ]
                [ a [ class "has-text-black-ter", onClick LoadSystems, href "#Konfiguration" ] [] ]

          else
            button [ class "button is-warning mr-2" ]
                [ a [ class "has-text-black-ter", onClick LoadSystems, href "#Konfiguration" ] [ text "Laden" ] ]
        ]


viewSystemLibary : List System -> Html Msg
viewSystemLibary systList =
    div [ class "container", Html.Attributes.style "height" "100vh" ]
        [ div [ class "fixed-grid has-4-cols mt-4" ]
            [ div [ class "grid mx-2" ]
                (div
                    [ class "card has-background-white px-4 has-text-centered animate__animated animate__bounce animate__fadeIn duration-2s"
                    , onClick (OpenModal OpenInputSystem)
                    ]
                    [ div [ class "card-header has-text-black is-size-3" ] [ text "Neues System" ]
                    , div [ class "card-image has-text-centered" ]
                        [ figure [ class "image is-128x128 is-inline-block mt-2" ]
                            [ img [ src "https://imgs.search.brave.com/iBLTlsPMOjQxfPpIJ7RHEPFtaTba4KObnOiflagAf0E/rs:fit:860:0:0/g:ce/aHR0cHM6Ly9jZG4w/Lmljb25maW5kZXIu/Y29tL2RhdGEvaWNv/bnMvcm91bmQtdWkt/aWNvbnMvNTEyL2Fk/ZF9ncmVlbi5wbmc" ] []
                            ]
                        ]
                    ]
                    :: (systList
                            |> List.map
                                (\s ->
                                    div
                                        [ class "card has-background-white px-4 has-text-centered animate__animated animate__bounce animate__fadeIn duration-2s"
                                        , onClick (OpenModal (OpenShowSystem s))
                                        ]
                                        [ div [ class "card-header has-text-black is-size-3" ] [ text s.name ]
                                        , div [ class "card-image" ]
                                            [ figure [ class "image is-full-width mt-3" ]
                                                [ img [ src s.url ] []
                                                ]
                                            ]
                                        ]
                                )
                       )
                )
            ]
        ]


systemList : SystemLoadingState -> List System
systemList loadingSyst =
    case loadingSyst of
        SuccessS syst ->
            syst

        FailureS ->
            []

        LoadingS ->
            []

        NoneS ->
            []


getSystemNames : SystemLoadingState -> List String
getSystemNames loadingSyst =
    case loadingSyst of
        SuccessS syst ->
            List.map (\s -> s.name) syst

        FailureS ->
            [ "Bitte neu laden" ]

        LoadingS ->
            [ "Loading" ]

        NoneS ->
            []


inputSystemInModal : System -> Html Msg
inputSystemInModal s =
    div [ class "modal is-active" ]
        [ div [ class "modal-background" ] []
        , div [ class "modal-card" ]
            [ div [ class "modal-card-head" ]
                [ h2 [ class "modal-card-title title is-3" ] [ text "Neues System anlegen" ]
                ]
            , section [ class "modal-card-body" ]
                [ inputSystem s
                ]
            , footer [ class "modal-card-foot" ]
                [ button [ class "button is-link mr-4" ]
                    [ a [ class "has-text-white", onClick (OpenModal (AddS s)) ] [ text "Anlegen" ] ]
                , button [ class "button is-danger" ] [ a [ class "has-text-white", onClick CloseModal, href "#Konfiguration" ] [ text "Schliessen" ] ]
                ]
            ]
        ]


inputSystem : System -> Html Msg
inputSystem s =
    let
        changeName newName =
            OpenModal (ChangeS { s | name = newName })

        changeURL newURL =
            OpenModal (ChangeS { s | url = newURL })
    in
    fieldset []
        [ div [ class "has-text-weight-semibold is-size-5" ]
            [ text "System"
            , input [ class "input", type_ "text", value s.name, onInput changeName, placeholder "Name des Systems" ] []
            ]
        , div [ class "has-text-weight-semibold is-size-5" ]
            [ text "Url"
            , input [ class "input", type_ "text", value s.url, onInput changeURL, placeholder "Bildadresse" ] []
            ]
        ]


showSystemInModal : System -> Html Msg
showSystemInModal s =
    let
        changeURL newURL =
            OpenModal (ChangeS { s | url = newURL })
    in
    div [ class "modal is-active" ]
        [ div [ class "modal-background" ] []
        , div [ class "modal-card" ]
            [ div [ class "modal-card-head" ]
                [ h2 [ class "title is-3" ] [ text s.name ] ]
            , section [ class "modal-card-body" ]
                [ fieldset []
                    [ div [ class "has-text-weight-semibold is-size-5" ]
                        [ text "Url"
                        , input [ class "input", type_ "text", value s.url, onInput changeURL ] []
                        ]
                    ]
                ]
            , footer [ class "modal-card-foot" ]
                [ button [ class "button is-link mr-4" ]
                    [ a [ class "has-text-white", onClick (OpenModal (AddS s)), href "#Konfiguration" ] [ text "Speichern" ]
                    ]
                , button [ class "button is-warning mr-4" ]
                    [ a [ class "has-text-white", onClick (OpenModal (AddS s)), href "#Konfiguration" ] [ text "Löschen" ]
                    ]
                , button [ class "button is-danger" ] [ a [ class "has-text-white", onClick CloseModal, href "#Konfiguration" ] [ text "Schliessen" ] ]
                ]
            ]
        ]
