module Types exposing (..)

import Browser
import Browser.Navigation as Nav
import Date exposing (Date)
import Http
import List.Extra exposing (find)
import Url


type alias Model =
    { modal : Maybe ModalState
    , saved : Reservation
    , loadingRes : LoadingState
    , loadingSystem : SystemLoadingState
    , date : Date
    , status : Status
    , key : Nav.Key
    , url : Url.Url
    }


type ModalState
    = ShowCalendar
    | ShowReservation
    | InputReservation Reservation SystemLoadingState
    | ShowSystem System
    | InputSystem System


type LoadingState
    = Loading
    | Failure
    | Success (List Reservation)
    | None


type alias Reservation =
    { date : String
    , hour : Int
    , dm : String
    , system : String
    }


type alias ReservationJson =
    { res : List Reservation
    }


type Status
    = Free
    | Taken
    | Unknown


type SystemLoadingState
    = FailureS
    | LoadingS
    | SuccessS (List System)
    | NoneS


type alias System =
    { name : String
    , url : String
    }


type alias SystemJson =
    { syst : List System
    }



-- UPDATE


type Msg
    = SetDate Date
    | OpenModal ModalMsg
    | CloseModal
    | LoadReservations
    | GotReservations (Result Http.Error (List Reservation))
    | LoadSystems
    | GotSystems (Result Http.Error (List System))
    | ClickedLink Browser.UrlRequest
    | UrlChanged Url.Url


type ModalMsg
    = OpenShowCalendar
    | OpenShowReservation
    | OpenInputReservation Date
    | Change Reservation
    | Add Reservation
    | OpenInputSystem
    | OpenShowSystem System
    | ChangeS System
    | AddS System



-- HELPERS


getStatus : Date -> LoadingState -> Status
getStatus date loading =
    case loading of
        Loading ->
            Unknown

        Failure ->
            Unknown

        None ->
            Free

        Success reservations ->
            let
                result =
                    find (\r -> r.date == Date.toIsoString date) reservations
            in
            case result of
                Nothing ->
                    Free

                Just r ->
                    Taken
